==> openliberty-src-20.0.0.2.zip: open-liberty-gm-20.0.0.2/dev/com.ibm.ws.ejbcontainer.timer.persistent_fat/test-applications/NoDBPersistAutoTimerEJB.jar/src/com/ibm/ws/ejbcontainer/timer/nodb/pauto/ejb/PAutoTimerBean.java <==
/*******************************************************************************
 * Copyright (c) 2018 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package com.ibm.ws.ejbcontainer.timer.nodb.pauto.ejb;

import java.util.concurrent.CountDownLatch;
import java.util.concurrent.TimeUnit;
import java.util.logging.Logger;

import javax.annotation.Resource;
import javax.ejb.LocalBean;
import javax.ejb.NoSuchObjectLocalException;
import javax.ejb.Schedule;
import javax.ejb.Stateless;
import javax.ejb.Timer;
import javax.ejb.TimerService;

/**
 * A simple stateless bean with persistent automatically created timers and methods
 * to verify the timers would run as expected if persistent timers supported.
 */
@Stateless
@LocalBean
public class PAutoTimerBean {

    private static final Logger logger = Logger.getLogger(PAutoTimerBean.class.getName());

    private static final CountDownLatch autoTimerLatch = new CountDownLatch(1);

    @Resource
    private TimerService ts;

    @Schedule(hour = "*", minute = "*", second = "*", info = "PAutoTimerBean", persistent = true)
    public void timeout(Timer timer) {
        logger.info("timeout : " + timer);
        autoTimerLatch.countDown();
        timer.cancel();
    }

    // Intentionally non-persistent; should not matter since application should fail to start
    @Schedule(year = "2075", hour = "*", minute = "*", second = "*", info = "Future-PAutoTimerBean", persistent = false)
    public void futureTimeout(Timer timer) {
        logger.info("futureTimeout : " + timer);
        timer.cancel();
    }

    public boolean waitForAutomaticTimer() {
        logger.info("> waitForAutomaticTimer");
        try {
            autoTimerLatch.await(30, TimeUnit.SECONDS);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        boolean timedout = autoTimerLatch.getCount() == 0;
        logger.info("< waitForAutomaticTimer : " + timedout);
        return timedout;
    }

    public void clearAllTimers() {
        for (Timer timer : ts.getTimers()) {
            try {
                logger.info("clearAllTimers : " + timer);
                timer.cancel();
            } catch (NoSuchObjectLocalException ex) {
                logger.info("clearAllTimers : " + ex);
            }
        }
    }
}

==> openliberty-src-20.0.0.11.zip: open-liberty-gm-20.0.0.11/dev/com.ibm.ws.ejbcontainer.timer.persistent_fat/test-applications/NoDBPersistAutoTimerEJB.jar/src/com/ibm/ws/ejbcontainer/timer/nodb/pauto/ejb/PAutoTimerBean.java <==
/*******************************************************************************
 * Copyright (c) 2018, 2020 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package com.ibm.ws.ejbcontainer.timer.nodb.pauto.ejb;

import java.util.concurrent.CountDownLatch;
import java.util.concurrent.TimeUnit;
import java.util.logging.Logger;

import javax.annotation.Resource;
import javax.ejb.LocalBean;
import javax.ejb.NoSuchObjectLocalException;
import javax.ejb.Schedule;
import javax.ejb.Stateless;
import javax.ejb.Timer;
import javax.ejb.TimerService;

import com.ibm.websphere.ejbcontainer.test.tools.FATHelper;

/**
 * A simple stateless bean with persistent automatically created timers and methods
 * to verify the timers would run as expected if persistent timers supported.
 */
@Stateless
@LocalBean
public class PAutoTimerBean {

    private static final Logger logger = Logger.getLogger(PAutoTimerBean.class.getName());

    private static final CountDownLatch autoTimerLatch = new CountDownLatch(1);
    private static long POST_INVOKE_FUDGE_FACTOR = 400; //ms

    @Resource
    private TimerService ts;

    @Schedule(hour = "*", minute = "*", second = "*", info = "PAutoTimerBean", persistent = true)
    public void timeout(Timer timer) {
        logger.info("timeout : " + timer);
        autoTimerLatch.countDown();
        timer.cancel();
    }

    // Intentionally non-persistent; should not matter since application should fail to start
    @Schedule(year = "2075", hour = "*", minute = "*", second = "*", info = "Future-PAutoTimerBean", persistent = false)
    public void futureTimeout(Timer timer) {
        logger.info("futureTimeout : " + timer);
        timer.cancel();
    }

    public boolean waitForAutomaticTimer() {
        logger.info("> waitForAutomaticTimer");
        try {
            autoTimerLatch.await(30, TimeUnit.SECONDS);
            FATHelper.sleep(POST_INVOKE_FUDGE_FACTOR);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        boolean timedout = autoTimerLatch.getCount() == 0;
        logger.info("< waitForAutomaticTimer : " + timedout);
        return timedout;
    }

    public void clearAllTimers() {
        for (Timer timer : ts.getTimers()) {
            try {
                logger.info("clearAllTimers : " + timer);
                timer.cancel();
            } catch (NoSuchObjectLocalException ex) {
                logger.info("clearAllTimers : " + ex);
            }
        }
    }
}
